// Define views path
document.viewsPath = 'views/';

var app = angular.module('MyApp', [
	'ngResource', 
	'ngRoute',
	'ngSanitize', 
	'ngAnimate',
	'ngCookies',
	'ngLocalize',
	'ngLocalize.InstalledLanguages',
	'ui.bootstrap', 
	'ui.select',
	'frapontillo.bootstrap-switch',
	'datatables', 
	'datatables.bootstrap',
	'datatables.colvis',
	'datatables.tabletools',  
	'pascalprecht.translate',
	'toastr',
	'pageslide-directive',
	'selectize',	
	'sharedProvidersModule',
	'RWADODataAuth_plugin'		
]);

// Configure http interceptors and routingConfiguration
app.config(function ($routeProvider, $httpProvider) {
	//Enable cross domain calls
    $httpProvider.defaults.useXDomain = true;
    //Send all requests, even OPTIONS, with credentials
	$httpProvider.defaults.withCredentials = true;

	$httpProvider.defaults.headers.common = {};
	$httpProvider.defaults.headers.post = {};
	$httpProvider.defaults.headers.put = {};
	$httpProvider.defaults.headers.patch = {};

	$httpProvider.interceptors.push('httpRequestInterceptor');
	$httpProvider.interceptors.push('HTTPRequestsLoggingInerceptor');

	$routeProvider
		.when('/login', {
			controller: 'LoginController',
			templateUrl: 'js/plugins/rwad_auth/views/login.html',
			hideMenus: true
		})
		.when('/logout', {
			controller: 'LogoutController',
			templateUrl: 'js/plugins/rwad_auth/views/logout.html',
		})

		.when('/UserManagement/Users', {
			controller: 'UsersController',
			templateUrl: 'js/plugins/rwad_auth/views/users-list.html'			
		})
		.when('/UserManagement/Roles', {
			controller: 'RolesController',
			templateUrl: 'js/plugins/rwad_auth/views/roles-list.html'
		})
		.otherwise({ redirectTo: '/UserManagement/Users' });
});

// Define Определение дефолтной конфигурации angular-select
app.config(function(uiSelectConfig) {
	uiSelectConfig.theme = 'bootstrap';
	uiSelectConfig.resetSearchInput = true;
});

// Define logging level
app.config(function($logProvider) {
	$logProvider.debugEnabled(true);
});

// Toastr config
app.config(function(toastrConfig) {
  angular.extend(toastrConfig, {
    allowHtml: true,
    closeButton: false,
    closeHtml: '<button>&times;</button>',
    containerId: 'toast-container',
    extendedTimeOut: 1000,
    iconClasses: {
      error: 'toast-error',
      info: 'toast-info',
      success: 'toast-success',
      warning: 'toast-warning'
    },
    maxOpened: 0,
    messageClass: 'toast-message',
    newestOnTop: true,
    onHidden: null,
    onShown: null,
    positionClass: 'toast-bottom-right',
    preventDuplicates: false,
    tapToDismiss: true,
    target: 'body',
    timeOut: 5000,
    titleClass: 'toast-title',
    toastClass: 'toast'
  });
});

// Configure Authentication
app.run(['$rootScope', '$location', '$cookieStore', '$http', 'settingsSvc', 'interceptorsMessagesInitialiser',
    function ($rootScope, $location, $cookieStore, $http, settingsSvc, interceptorsMessagesInitialiser) {
    	
    	// Initialise request interceptors messages localization
		interceptorsMessagesInitialiser.Initialise();

    	$rootScope.globals = $cookieStore.get(document.ProjectName) || {};
        if ($rootScope.globals.currentUser) {
        	var authConfig = settingsSvc.GetAuthConfig();
        	if (authConfig.authType === 'Basic')
            	$http.defaults.headers.common['Authorization'] = 'Basic ' + $rootScope.globals.currentUser.authdata;
            else
            	$http.defaults.headers.common['Authorization'] = $rootScope.globals.currentUser.authdata;
        }

        $rootScope.$on('$locationChangeStart', function (event, next, current) {
            // Broadcast signal of location change to handle in nav crumbs and menu
            $rootScope.$broadcast('locationChange');

            if ($location.path() !== '/login' && !$rootScope.globals.currentUser) {
                $location.path('/login');
            }
            
        });
    }]);


app.value('localeSupported', [
    'en-US',
    'ru-RU'
]);
app.value('localeFallbacks', {
    'en': 'en-US',
    'ru': 'ru-RU'
});
